# autoretriever

A simple data retriever chat, built on [AutoGen framework](https://microsoft.github.io/autogen/docs/Getting-Started/).

It is a simplified version of autoretriever, which is integrated as part of [LetMeDoIt AI project](https://github.com/eliranwong/letmedoit)

# Install

> pip install autoretriever

# Usage

> autoretriever
